@@ -26,7 +26,6 @@
  * USA
  */
 
-#include <config.h>
 #include <string.h>
 #include <gnome.h>
 
@@ -90,7 +89,7 @@ struct _GkbPropertyBoxInfo
 struct _GkbKeymap
 {
   gint i;
-  GdkPixmap *pix;
+  GdkPixbuf *pixbuf;
 
   gchar *name;
   gchar *command;
@@ -127,9 +126,10 @@ struct _GKB
   GtkWidget *label_frame1;
   GtkWidget *label2;
   GtkWidget *label_frame2;
-  GtkWidget *darea;
   GtkWidget *darea_frame;
+  GtkWidget *image;
   GtkWidget *addwindow;
+  GtkTooltips *tooltips;
 
   gint n;
   gint cur;
@@ -168,7 +168,7 @@ struct _GkbKeymapWg
 /* gkb.c */
 void gkb_update (GKB *gkb, gboolean set_command);
 void alert (const gchar * str);
-void applet_save_session ();
+void applet_save_session (void);
 
 /* prop.c */
 void gkb_apply (GkbPropertyBoxInfo * pbi);
