@@ -30,6 +30,10 @@
  * USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gkb.h"
 
 typedef struct _GkbMapDialogInfo GkbMapDialogInfo;
