@@ -1,8 +1,6 @@
 #ifndef __GLOBAL_H__
 #define __GLOBAL_H__
 
-#include <config.h>
-
 #include <gnome.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
@@ -44,14 +42,16 @@ struct _LoadGraph {
     GdkPixmap *pixmap;
     GdkGC *gc;
     int timer_index;
+    GtkTooltips *tooltips;
 
     gint show_frame;
 
     long cpu_time [NCPUSTATES];
     long cpu_last [NCPUSTATES];
     int cpu_initialized;
-    
+
     gboolean visible;
+    gboolean tooltip_update;
     gchar *name;
 };
 
@@ -68,6 +68,8 @@ struct _MultiloadApplet
 	gboolean view_netload;
 	gboolean view_swapload;
 	gboolean view_loadavg;
+	
+	GtkWidget *check_boxes[5];
 };
 
 #include "load-graph.h"
@@ -105,9 +107,9 @@ multiload_properties_cb(BonoboUIComponent *uic, gpointer data, const gchar *name
 void
 multiload_applet_refresh(MultiloadApplet *ma);
 
-/* show help */
+/* update the tooltip to the graph's current "used" percentage */
 void
-multiload_help_cb (BonoboUIComponent *uic, gpointer data, const gchar *name);
+multiload_applet_tooltip_update(LoadGraph *g);
 
 G_END_DECLS
 
